@@ -2,7 +2,7 @@
 #
 #       codeboxes.py
 #
-#       Copyright 2009-2015 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2016 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -252,8 +252,8 @@ class CodeBoxesHandler:
             anchor.sourcebuffer.set_modified(False)
         anchor.sourceview = gtksourceview2.View(anchor.sourcebuffer)
         anchor.sourceview.set_smart_home_end(gtksourceview2.SMART_HOME_END_AFTER)
-        if self.dad.highl_curr_line: anchor.sourceview.set_highlight_current_line(True)
-        if self.dad.show_white_spaces: anchor.sourceview.set_draw_spaces(DRAW_SPACES_FLAGS)
+        anchor.sourceview.set_highlight_current_line(self.dad.pt_highl_curr_line)
+        if self.dad.pt_show_white_spaces: anchor.sourceview.set_draw_spaces(DRAW_SPACES_FLAGS)
         if anchor.syntax_highlighting == cons.PLAIN_TEXT_ID:
             anchor.sourceview.modify_font(pango.FontDescription(self.dad.text_font))
         else:
@@ -397,7 +397,7 @@ class CodeBoxesHandler:
         elif event.type == gtk.gdk.BUTTON_PRESS:
             return support.on_sourceview_event_after_button_press(self.dad, text_view, event)
         elif event.type == gtk.gdk.KEY_PRESS:
-            return support.on_sourceview_event_after_key_press(self.dad, text_view, event)
+            return support.on_sourceview_event_after_key_press(self.dad, text_view, event, self.curr_codebox_anchor.syntax_highlighting)
         return False
 
     def on_vscrollbar_event_after(self, vscrollbar, event, anchor):
