@@ -22,7 +22,7 @@
 import os, sys
 
 
-VERSION = "0.36.6"
+VERSION = "0.36.8"
 APP_NAME = "cherrytree"
 NEWER_VERSION_URL = "http://www.giuspen.com/software/version_cherrytree"
 if sys.platform.startswith("win"):
@@ -159,7 +159,11 @@ CHAR_LISTDONEFAIL= "☒"
 CHAR_TILDE = "~"
 CHAR_MINUS = "-"
 CHAR_DQUOTE = '"'
+CHAR_SMART_DQUOTE_0 = '“'
+CHAR_SMART_DQUOTE_1 = '”'
 CHAR_SQUOTE = "'"
+CHAR_SMART_SQUOTE_0 = "‘"
+CHAR_SMART_SQUOTE_1 = "’"
 CHAR_SLASH = "/"
 CHAR_BSLASH = "\\"
 CHAR_SQ_BR_OPEN = "["
@@ -208,6 +212,9 @@ STR_KEY_UP = "Up"
 STR_KEY_DOWN = "Down"
 STR_KEY_LEFT = "Left"
 STR_KEY_RIGHT = "Right"
+STR_KEY_DQUOTE = "quotedbl"
+STR_KEY_SQUOTE = "apostrophe"
+STR_KEYS_CONTROL = ["Control_L", "Control_R"]
 STR_PYGTK_222_REQUIRED = "PyGTK 2.22 required"
 
 HTML_HEADER = '''<!doctype html><html>
