@@ -2,7 +2,7 @@
 #
 #       machines.py
 #
-#       Copyright 2009-2015 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2016 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -753,12 +753,12 @@ class StateMachine:
     def load_embedded_image_element(self, text_buffer, element):
         """Load an Image from the Embedded Vector into the Buffer"""
         iter_insert = text_buffer.get_iter_at_offset(element[0])
-        self.dad.image_insert(iter_insert, element[1], element[2])
+        self.dad.image_insert(iter_insert, element[1], element[2], text_buffer=text_buffer)
 
     def load_embedded_table_element(self, text_buffer, element):
         """Load a Table from the Embedded Vector into the Buffer"""
         iter_insert = text_buffer.get_iter_at_offset(element[0])
-        self.dad.tables_handler.table_insert(iter_insert, element[1], element[2])
+        self.dad.tables_handler.table_insert(iter_insert, element[1], element[2], text_buffer=text_buffer)
 
     def load_embedded_codebox_element(self, text_buffer, element):
         """Load a CodeBox from the Embedded Vector into the Buffer"""
@@ -790,11 +790,6 @@ class StateMachine:
 
     def reset(self):
         """State Machine Reset"""
-        del self.nodes_vectors
-        del self.nodes_indexes
-        del self.nodes_indicators
-        del self.visited_nodes_list
-        del self.visited_nodes_idx
         self.nodes_vectors = {}
         self.nodes_indexes = {}
         self.nodes_indicators = {}
@@ -820,11 +815,6 @@ class StateMachine:
             #print "last_index",  len(self.visited_nodes_list) - 1
             return None
 
-    def forget_last_visited(self):
-        """Remove the latest element from the list of the visited nodes"""
-        self.visited_nodes_idx -= 1
-        self.visited_nodes_list.pop()
-
     def node_selected_changed(self, node_id):
         """When a New Node is Selected"""
         if not self.dad.go_bk_fw_click:
